@@ -1,9 +1,11 @@
 package Text::Password::SHA;
-our $VERSION = "0.17";
+our $VERSION = "0.18";
 
 use Moo;
-use Carp;
+use strictures 2;
 use Crypt::Passwd::XS;
+
+use autouse 'Carp'        => qw(croak carp);
 use autouse 'Digest::SHA' => qw(sha1_hex);
 
 use Types::Standard qw(Int);
@@ -21,7 +23,7 @@ Text::Password::SHA - generate and verify Password with SHA
 =head1 SYNOPSIS
 
  my $pwd = Text::Password::SHA->new();
- my( $raw, $hash ) = $pwd->genarate();          # list context is required
+ my( $raw, $hash ) = $pwd->generate();          # list context is required
  my $input = $req->body_parameters->{passwd};
  my $data = $pwd->encrypt($input);              # you don't have to care about salt
  my $flag = $pwd->verify( $input, $data );
@@ -42,7 +44,7 @@ No arguments are required. But you can set some arguments.
 
 You can set other length to 'default' like below:
 
- $pwd = Text::Pasword::AutoMiglation->new( default => 8 );
+ $pwd = Text::Password::AutoMiglation->new( default => 8 );
 
 =item readablity( I<Bool> )
 
@@ -55,8 +57,10 @@ You can let passwords to be more secure with setting I<readablity =E<lt> 0>.
 
 Then you can generate stronger passwords with I<generate()>.
 
- $pwd = Text::Pasword::AutoMiglation->new( readability => 0 ); # or
- $pwd->readability(0);
+$pwd = Text::Password::AutoMiglation->new( readability => 0 );
+
+# or $pwd->readability(0);
+
 
 =back
 
@@ -99,15 +103,14 @@ salt will be made automatically.
 
 sub encrypt {
     my ( $self, $input ) = @_;
-    croak ref $self, " requires a strings longer than at least ", Min if length($input) < Min;
-    croak ref $self, " doesn't allow any Wide Characters or white spaces" if $input =~ /[^ -~]/;
+    croak ref $self, " requires a strings longer than at least ", Min if length $input < Min;
+    croak ref $self, " doesn't allow any Wide Characters or control codes" if $input =~ /[^ -~]/;
     return Crypt::Passwd::XS::unix_sha512_crypt( $input, $self->nonce() );
-
 }
 
 =head3 generate( I<Int> )
 
-genarates pair of new password and it's hash.
+generates pair of new password and its hash.
 
 less readable characters(I<0Oo1Il|!2Zz5sS$6b9qCcKkUuVvWwXx.,:;~-^'"`>) are forbidden
 unless $self->readability is 0.
